@@ -1,8 +1,4 @@
 package Devel::ebug::Console;
-
-our $VERSION = '0.62_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
-
 use strict;
 use warnings;
 use lib 'lib';
@@ -10,87 +6,65 @@ use Carp;
 use Class::Accessor::Chained::Fast;
 use Devel::ebug;
 use Term::ReadLine;
+use YAML;
 use base qw(Class::Accessor::Chained::Fast);
 
 sub run {
   my $self = shift;
-  my $backend = shift;
 
-  $SIG{INT} = sub {
-    die "INT";
-  };
-
-  my $filename = join " ", @ARGV;
-
-  unless ($filename) {
-    $filename = '-e "Interactive ebugging shell"';
-  }
+  my $filename = join "", @ARGV;
+  croak("Devel::ebug::Console: No filename passed in run()") unless $filename;
 
   my $ebug = Devel::ebug->new;
   $ebug->program($filename);
-  $ebug->backend($backend);
   $ebug->load;
 
-  my $codelines = {};
+  my $codelines;
 
   print "* Welcome to Devel::ebug $Devel::ebug::VERSION\n";
 
   my $term = Term::ReadLine->new('ebug');
-  my $attribs = $term->Attribs;
-  $attribs->{completion_function} = sub {
-    my ($text, $line, $start) = @_;
-    my $pad = $ebug->pad || {};
-    return unless $line =~ s/^x //;
-    my @result = grep { /^\Q$line/ } keys %$pad;
-    if ($line =~ /^[\$\@]/) {
-      s/^[\$\@]// for @result;
-    }
-    return @result;
-  };
   my $last_command = "s";
   my $list_always = 0;
   my $list_lines_count = 9;
 
   while (1) {
     if ($ebug->finished) {
-      print "ebug: Program finished. Enter 'restart' or 'q'\n";
-    } else {
-      if ($list_always) {
-        show_codelines($codelines, $ebug, $list_lines_count) if($list_always);
-      } else {
-        print $ebug->subroutine
-        . "(" . $ebug->filename . "#" . $ebug->line . "):\n"
-        . $ebug->codeline, "\n";
-      }
+      print "ebug: Program finished, restarting!\n";
+      $ebug->load;
     }
 
+    if($list_always) {
+      show_codelines($codelines, $ebug, $list_lines_count) if($list_always);
+    } else {
+      print $ebug->subroutine
+	. "(" . $ebug->filename . "#" . $ebug->line . "): "
+	. $ebug->codeline, "\n";
+    }
     my $command = $term->readline("ebug: ");
     $command = "q" if not defined $command;
     $command = $last_command if ($command eq "");
 
-    if ($command =~ /^\s*[?h](elp)?\s*$/) {
+    if ($command eq 'h') {
       print 'Commands:
 
-      b Set break point at a line number (eg: b 6, b code.pl 6, b code.pl 6 $x > 7,
+    b Set break point at a line number (eg: b 6, b code.pl 6, b code.pl 6 $x > 7,
       b Calc::fib)
-     bf break on file loading (eg: bf Calc.pm)
-      d Delete a break point (d 6, d code.pl 6)
-      e Eval Perl code and print the result (eg: e $x+$y)
-      f Show all the filenames loaded
-      l List codelines or set number of codelines to list (eg: l, l 20)
-      L List codelines always (toggle)
-      n Next (steps over subroutine calls)
-      o Output (show STDOUT, STDERR)
-      p Show pad
-      r Run until next break point or watch point
-    ret Return from subroutine  (eg: ret, ret 3.141)
-restart Restart the program
-      s Step (steps into subroutine calls)
-      T Show a stack trace
-      u Undo (eg: u, u 4)
-      w Set a watchpoint (eg: w $t > 10)
-      x Dump a variable using YAML (eg: x $object)
-      q Quit
+    d Delete a break point (d 6, d code.pl 6)
+    e Eval Perl code and print the result (eg: e $x+$y)
+    f Show all the filenames loaded
+    l List codelines or set number of codelines to list (eg: l, l 20)
+    L List codelines always (toggle)
+    n Next (steps over subroutine calls)
+    p Show pad
+    r Run until next break point or watch point
+  ret Return from subroutine  (eg: ret, ret 3.141)
+    s Step (steps into subroutine calls)
+    T Show a stack trace
+    u Undo (eg: u, u 4)
+    w Set a watchpoint (eg: w $t > 10)
+    y Dump a variable using YAML (eg: d $x)
+    q Quit
 ';
     } elsif ($command eq 'l') {
       show_codelines($codelines, $ebug, $list_lines_count);
@@ -102,29 +76,27 @@ restart Restart the program
     } elsif ($command eq 'p') {
       my $pad = $ebug->pad_human;
       foreach my $k (sort keys %$pad) {
-        my $v = $pad->{$k};
-        print "  $k = $v;\n";
+	my $v = $pad->{$k};
+	print "  $k = $v;\n";
       }
     } elsif ($command eq 's') {
       $ebug->step;
+    } elsif ($command =~ /^e (.+)/) {
+      my $v = $ebug->eval($1) || "";
+      print "$v\n";
+    } elsif ($command =~ /^y (.+)/) {
+      my $v = $ebug->eval($1) || "";
+      print Dump($v);
     } elsif ($command eq 'n') {
       $ebug->next;
-    } elsif ($command eq 'o') {
-      my($stdout, $stderr) = $ebug->output;
-      print "STDOUT:\n$stdout\n";
-      print "STDERR:\n$stderr\n";
     } elsif ($command eq 'r') {
       $ebug->run;
-      # TODO: Consider using this instead:
-      # eval { $ebug->run };
-    } elsif ($command eq 'restart') {
-      $ebug->load;
     } elsif ($command =~ /^ret ?(.*)/) {
       $ebug->return($1);
     } elsif ($command eq 'T') {
       my @trace = $ebug->stack_trace_human;
       foreach my $frame (@trace) {
-        print "$frame\n";
+	print "$frame\n";
       }
     } elsif ($command eq 'f') {
       print "$_\n" foreach $ebug->filenames;
@@ -135,8 +107,6 @@ restart Restart the program
       $ebug->break_point($1, $2, $3);
     } elsif ($command =~ /^b (.+)/) {
       $ebug->break_point_subroutine($1);
-    } elsif ($command =~ /^bf (.+)/) {
-      $ebug->break_on_load($1);
     } elsif ($command =~ /^d (.+?) (\d+)/) {
       $ebug->break_point_delete($1, $2);
     } elsif ($command =~ /^d (\d+)/) {
@@ -148,16 +118,8 @@ restart Restart the program
       $ebug->undo($1);
     } elsif ($command eq 'q') {
       exit;
-    } elsif ($command =~ /^x (.+)/) {
-      my $v = $ebug->eval("use YAML; Dump($1)") || "";
-      print "$v\n";
-    } elsif ($command =~ /^e (.+)/) {
-      my $v = $ebug->eval($1) || "";
-      print "$v\n";
-    } elsif ($command) {
-      my $v = $ebug->eval($command) || "";
-      print "$v\n";
-
+    } else {
+      print "Unknown ebug command '$command'!\n";
     }
     $last_command = $command;
   }
@@ -196,17 +158,9 @@ sub show_codelines {
 
 __END__
 
-=pod
-
-=encoding UTF-8
-
 =head1 NAME
 
-Devel::ebug::Console
-
-=head1 VERSION
-
-version 0.62_01
+Devel::ebug::Console - Console front end to Devel::ebug
 
 =head1 SYNOPSIS
 
@@ -217,34 +171,20 @@ version 0.62_01
 
 =head1 DESCRIPTION
 
-L<Devel::ebug::Console> is an interactive command-line front end to L<Devel::ebug>. It
+L<Devel::ebug::Console> is an interactive commmand-line front end to L<Devel::ebug>. It
 is a simple Perl debugger, much like perl5db.pl.
 
-=head1 NAME
-
-Devel::ebug::Console - Console front end to Devel::ebug
-
 =head1 SEE ALSO
 
 L<Devel::ebug>, L<ebug>
 
 =head1 AUTHOR
 
-Original author: Leon Brocard E<lt>acme@astray.comE<gt>
+Leon Brocard, C<< <acme@astray.com> >>
 
-Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
+=head1 COPYRIGHT
 
-Contributors:
+Copyright (C) 2005, Leon Brocard
 
-Brock Wilcox E<lt>awwaiid@thelackthereof.orgE<gt>
-
-Taisuke Yamada
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2005-2020 by Leon Brocard.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
+This program is free software; you can redistribute it or modify it
+under the same terms as Perl itself.
