@@ -1,13 +1,7 @@
 package Devel::ebug::Plugin::Run;
-
-use strict;
-use warnings;
 use base qw(Exporter);
 our @EXPORT = qw(undo run return step next);
 
-our $VERSION = '0.62_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
-
 # undo
 sub undo {
   my($self, $levels) = @_;
@@ -15,7 +9,7 @@ sub undo {
   my $response = $self->talk({ command => "commands" });
   my @commands = @{$response->{commands}};
   pop @commands foreach 1..$levels;
-#  use YAML; warn Dump \@commands;
+
   my $proc = $self->proc;
   $proc->die;
   $self->load;
@@ -62,38 +56,3 @@ sub next {
 }
 
 1;
-
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-Devel::ebug::Plugin::Run
-
-=head1 VERSION
-
-version 0.62_01
-
-=head1 AUTHOR
-
-Original author: Leon Brocard E<lt>acme@astray.comE<gt>
-
-Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
-
-Contributors:
-
-Brock Wilcox E<lt>awwaiid@thelackthereof.orgE<gt>
-
-Taisuke Yamada
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2005-2020 by Leon Brocard.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
