@@ -1,19 +1,13 @@
 package Devel::ebug::Plugin::StackTrace;
-
-use strict;
-use warnings;
 use Scalar::Util qw(blessed);
 use base qw(Exporter);
 our @EXPORT = qw(stack_trace stack_trace_human stack_trace_human_args);
 
-our $VERSION = '0.62_01'; # TRIAL VERSION
-$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
-
 # return the stack trace
 sub stack_trace {
   my($self) = @_;
   my $response = $self->talk({ command => "stack_trace" });
-  return @{$response->{stack_trace}||[]};
+  return @{$response->{stack_trace}};
 }
 
 # return the stack trace in a human-readable format
@@ -79,38 +73,3 @@ sub stack_trace_human_args {
 }
 
 1;
-
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-Devel::ebug::Plugin::StackTrace
-
-=head1 VERSION
-
-version 0.62_01
-
-=head1 AUTHOR
-
-Original author: Leon Brocard E<lt>acme@astray.comE<gt>
-
-Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>
-
-Contributors:
-
-Brock Wilcox E<lt>awwaiid@thelackthereof.orgE<gt>
-
-Taisuke Yamada
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2005-2020 by Leon Brocard.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
